GPA(df, tolerance=10^-10, nbiteration=200, scale=TRUE,
coord=c(1,2), group, name.group = NULL, graph = TRUE)tolerancedf may have non described or non evaluated rows, i.e. rows with missing
values only.
The algorithm used here is the one developed by Commandeur.data(wine)
res.gpa <- GPA(wine[,-(1:2)], group=c(5,3,10,9,2),
name.group=c("olf","vis","olfag","gust","ens"))
### If you want to construct the partial points for some individuals only
plot.GPApartial (res.gpa)Run the code above in your browser using DataLab