Learn R Programming

FactoMineR (version 1.01)

plot.FDA: Factorial Discriminant Analysis graphs

Description

Plot the graphs for a Factorial Discriminant Analysis (FDA).

Usage

plot.FDA(x, choix="ind", axes=c(1,2), invisible=NULL, 
    xlim=NULL, ylim=NULL, col.grpe=NULL, lab.ind=FALSE, 
    lab.var=TRUE, lab.cg=TRUE, lab.ind.sup=FALSE, level.conf=0.95, ...)

Arguments

x
an object of class FDA
choix
the graph to plot ("ind" for the individuals, "var" for the variables)
axes
a length 2 vector specifying the components to plot
invisible
string indicating if some points should not be drawn ("ind", "cg", "elli" or "ind.sup")
xlim
range for the plotted 'x' values, defaulting to the range of the finite values of 'x'
ylim
range for the plotted 'y' values, defaulting to the range of the finite values of 'y'
col.grpe
a vector with the color to use for the individuals
lab.ind
boolean, if TRUE, the label of the individuals are drwan
lab.var
boolean, if TRUE, the label of the variables are drwan
lab.cg
boolean, if TRUE, the label of the centers of gravity are drwan
lab.ind.sup
boolean, if TRUE, the label of the supplementary individuals are drwan
level.conf
the confidence level of the ellipses
...
further arguments passed to or from other methods

See Also

FDA, print.FDA

Examples

Run this code
data(wine)
res.fda <- FDA(wine[,-(1:28)], fact=wine[,1], graph = FALSE)
plot(res.fda, choix="ind")
plot(res.fda, choix="var")

Run the code above in your browser using DataLab