Usage
plot.GPApartial(x, axes = c(1, 2),
lab.ind.moy = TRUE, lab.par = FALSE, habillage = "ind",
chrono = FALSE, draw.partial = NULL,
xlim = NULL, ylim = NULL, cex = 1, title = NULL, ...)Arguments
axes
a length 2 vector specifying the components to plot
lab.ind.moy
boolean, if TRUE, the label of the mean points are drwan
lab.par
boolean, if TRUE, the label of the partial points are drwan
habillage
string corresponding to the color which are used. If "ind", one color is used for each individual;
if "group" the individuals are colored according to the group
chrono
boolean, if TRUE, the partial points of a same point are linked (useful when groups correspond to different moment)
draw.partial
data frame of a boolean variable for all the individuals and all the centers of gravity and with for which the partial points should be drawn (by
default, NULL and no partial points are drawn)
xlim
range for the plotted 'x' values, defaulting to the range of the finite values of 'x'
ylim
range for the plotted 'y' values, defaulting to the range of the finite values of 'y'
cex
cf. function par in the graphics package title
string corresponding to the title of the graph you draw (by default NULL and a title is chosen)
...
further arguments passed to or from other methods