View source: R/plot.meansComp.R
| plot.meansComp | R Documentation |
Plot the graphs for the means comparisons.
## S3 method for class 'meansComp'
plot(x, theme = "theme_factominer", ...)
x |
an object of class meansComp. |
theme |
a character string corresponding to a theme you want to use for the graph, by default 'theme_factominer'. The theme 'ggplot2::theme_bw()' for instance are also possible. |
... |
further arguments passed to or from other methods, such as ggplot, ... |
Francois Husson francois.husson@institut-agro.fr
meansComp
data(senso)
res <- LinearModel(Score~ Product + Day , data=senso, selection="none")
meansComp(res,~Product)
## Not run:
## and with the sidak correction
meansComp(res,~Product,adjust="sidak")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.