theme_factominer: Theme for ggplot graphs and colour scales for FactoMineR

View source: R/theme_factominer.R

theme_factominerR Documentation

Theme for ggplot graphs and colour scales for FactoMineR

Description

theme_factominer for the ggplot graphs of FactoMineR.

Usage

theme_factominer(
    base_size         = 11,
    base_family       = "Inclusive Sans",
    title_family      = "Atkinson Hyperlegible Next",
    
    rel_title         = 1.5,
    rel_subtitle      = 1.05,
    rel_caption       = 0.78,
    rel_axis_title    = 0.9,
    rel_axis_text     = 0.85,
    rel_legend_title  = 0.88,
    rel_legend_text   = 0.85,
    rel_strip_text    = 0.9,
    
    # point_size        = 2.5,
    # label_size        = 3.5, 
    
    dark_text         = "#1C2B3A",
    mid_text          = "#4A5A6A",
    light_text        = "#7A8A9A",
    factominer_grid_col = "#E2E8F0"
)

scale_colour_factominer(...)
scale_fill_factominer(...)

scale_colour_factominer_contrib(name = "Contribution", limits = NULL, ...)
scale_fill_factominer_contrib(name = "Contribution", limits = NULL, ...)

scale_colour_factominer_cos2(name = "cos2", breaks = c(0, 0.25, 0.5, 0.75, 1), ...)
scale_fill_factominer_cos2(name = "cos2", breaks = c(0, 0.25, 0.5, 0.75, 1), ...)

scale_colour_factominer_coord(name = "Coordinate", midpoint = 0, ...)
scale_fill_factominer_coord(name = "Coordinate", midpoint = 0, ...)

scale_colour_factominer_pvalue(name = "p-valeur", threshold = 0.05, 
                               breaks = c(0, 0.001, 0.01, 0.05, 0.1, 0.5, 1), ...)
scale_fill_factominer_pvalue(name = "p-valeur", threshold = 0.05, 
                             breaks = c(0, 0.001, 0.01, 0.05, 0.1, 0.5, 1), ...)

geom_contrib_reference(n, ...)
factominer_breaks_contrib(max_val, n_breaks = 5)
factominer_breaks_cos2()
factominer_labels_pct(digits = 1)

Arguments

base_size

Base font size (default: 11).

base_family

Font family used for the main text (default: "Inclusive Sans"); choose in the google fonts

title_family

Font family used for titles (default: "Atkinson Hyperlegible Next"); choose in the google fonts.

rel_title

Relative size of title. Default 1.5

rel_subtitle

Relative size of subtitle. Default 1.05

rel_caption

Relative size of caption. Default 0.78

rel_axis_title

Relative size of axis_title. Default 0.9

rel_axis_text

Relative size of axis_text. Default 0.85

rel_legend_title

Relative size of legend_title. Default 0.88

rel_legend_text

Relative size of legend_text. Default 0.85

rel_strip_text

Relative size of strip_text. Default 0.9

dark_text

Color used for titles and dark text.

mid_text

Color used for regular text and legends.

factominer_grid_col

Color used for the grid.

light_text

Color used for axes and secondary legends.

name

Legend title.

limits

Limits of the scale.

breaks

Break points of the scale.

midpoint

Midpoint value for the diverging coordinate scale.

threshold

Significance threshold used to highlight p-values.

n

Number of individuals or variables used to compute the contribution reference line.

max_val

Maximum value used to compute scale breaks.

n_breaks

Desired number of scale breaks.

digits

Number of decimal places for percentages.

...

Additional arguments passed to the underlying ggplot2 functions.

Value

Object of class theme or scale structure for ggplot2.

Author(s)

F. Husson

Examples

data(decathlon)
res.pca <- PCA(decathlon,quali.sup=13,quanti.sup=11:12, graph=FALSE)
plot(res.pca)                                                          #theme by defaut
plot.PCA(res.pca, theme=theme_factominer(base_size=8, rel_title=1.2),  # smaller theme
   ggoptions = list(size=2.5))                                         # and smaller size
plot(res.pca,theme=ggplot2::theme_grey())                              # ggplot2 theme

FactoMineR documentation built on July 3, 2026, 1:08 a.m.