Learn R Programming

FactoMineR (version 1.01)

MCA: Multiple Correspondence Analysis (MCA)

Description

Performs Multiple Correspondence Analysis (MCA) with supplementary individuals, supplementary quantitative variables and supplementary qualitative variables.

Usage

MCA(X, ncp = 5, ind.sup = NULL, quanti.sup = NULL, 
    quali.sup = NULL, graph = TRUE)

Arguments

X
a data frame with n rows (individuals) and p columns (categorical variables)
ncp
number of dimensions kept in the results (by default 5)
ind.sup
a vector indicating the indexes of the supplementary individuals
quanti.sup
a vector indicating the indexes of the quantitative supplementary variables
quali.sup
a vector indicating the indexes of the qualitative supplementary variables
graph
boolean, if TRUE a graph is displayed

Value

  • Returns a list including:
  • eiga numeric vector containing all the eigenvalues
  • vara list of matrices containing all the results for the active variables (coordinates, square cosine, contributions, v.test)
  • inda list of matrices containing all the results for the active individuals (coordinates, square cosine, contributions)
  • ind.supa list of matrices containing all the results for the supplementary individuals (coordinates, square cosine)
  • quanti.supa matrix containing the coordinates of the supplementary quantitative variables (the correlation between a variable and an axis is equal to the variable coordinate on the axis)
  • quali.supa list of matrices with all the results for the supplementary qualitative variables (coordinates of each categories of each variables, square cosine and v.test which is a criterion with a Normal distribution)
  • calla list with some statistics
  • Returns the individuals factor map and the variables factor map.

See Also

print.MCA, plot.MCA

Examples

Run this code
data (poison)
MCA (poison, quali.sup = 3:4, quanti.sup = 1:2)

Run the code above in your browser using DataLab