Learn R Programming

FactoMineR (version 2.9)

print.CaGalt: Print the Correspondence Analysis on Generalised Aggregated Lexical Table (CaGalt) results

Description

Print the Correspondence Analysis on Generalised Aggregated Lexical Table (CaGalt) results

Usage

## S3 method for class 'CaGalt'
# S3 method for CaGalt
print(x, file = NULL, sep = ";", ...)

Arguments

x

an object of class CaGalt

file

A connection, or a character string naming the file to print to. If NULL (the default), the results are not printed in a file

sep

character string to insert between the objects to print (if the argument file is not NULL)

...

further arguments passed to or from other methods

Author

Belchin Kostov [email protected], Monica Becue-Bertaut, Francois Husson

See Also

CaGalt, write.infile

Examples

Run this code

if (FALSE) {
data(health)
res.cagalt<-CaGalt(Y=health[,1:115],X=health[,116:118],type="n")
print(res.cagalt)
}

Run the code above in your browser using DataLab